@@ -4,7 +4,7 @@ from typing import Optional, Union
 from osaft import log
 from osaft.core.backgroundfields import WaveType
 from osaft.core.frequency import Frequency
-from osaft.core.functions import SpecialFunctions as Sp
+from osaft.core.functions import BesselFunctions as Bf
 from osaft.core.geometries import Sphere
 from osaft.core.helper import InputHandler
 from osaft.core.helper import StringFormatter as SF
@@ -62,11 +62,11 @@ class ScatteringField(BaseYosioka, BaseScattering):
 
         # Dependencies
         self._A_n.is_computed_by(
-            self._labmda_rho, self.fluid._k_f,
+            self._lambda_rho, self.fluid._k_f,
             self.scatterer._k_f, self.sphere._R_0, self.field._A_in,
         )
         self._B_n.is_computed_by(
-            self._labmda_rho, self.fluid._k_f,
+            self._lambda_rho, self.fluid._k_f,
             self.scatterer._k_f, self.sphere._R_0, self.field._A_in,
         )
 
@@ -84,7 +84,7 @@ class ScatteringField(BaseYosioka, BaseScattering):
         )
 
     def __str__(self):
-        out = 'Yosioka\'s selfution to the Scattering field'
+        out = 'Yosioka\'s solution to the Scattering field'
         out += ' with following properties: \n'
         out += SF.get_str_text('Wave type', '', self.wave_type, '')
         out += SF.get_str_text('Frequency', 'f', self.f, 'Hz')
@@ -133,7 +133,7 @@ class ScatteringField(BaseYosioka, BaseScattering):
         return out
 
     # -------------------------------------------------------------------------
-    # User-faced functions
+    # User-facing functions
     # -------------------------------------------------------------------------
 
     def radial_particle_velocity(
@@ -152,7 +152,7 @@ class ScatteringField(BaseYosioka, BaseScattering):
         """
 
         def radial_func(l, x):
-            return self.B_n(l) * self.k_s * Sp.d1_besselj(l, self.k_s * x)
+            return self.B_n(l) * self.k_s * Bf.d1_besselj(l, self.k_s * x)
         r, theta, t = InputHandler.handle_input(
             r, theta, t, self.R_0,
             inside_sphere=True,
@@ -176,7 +176,7 @@ class ScatteringField(BaseYosioka, BaseScattering):
         """
 
         def radial_func(l, x):
-            return self.B_n(l) * Sp.besselj(l, self.k_s * x) / x
+            return self.B_n(l) * Bf.besselj(l, self.k_s * x) / x
         r, theta, t = InputHandler.handle_input(
             r, theta, t, self.R_0,
             inside_sphere=True,
@@ -223,7 +223,7 @@ class ScatteringField(BaseYosioka, BaseScattering):
         """
 
         def radial_func(l, x):
-            return self.field.A_in(l) * Sp.besselj(l, self.k_f * x)
+            return self.field.A_in(l) * Bf.besselj(l, self.k_f * x)
 
         out = self.radial_mode_superposition(radial_func, r, theta, t, mode)
         return out
@@ -243,7 +243,7 @@ class ScatteringField(BaseYosioka, BaseScattering):
         :param mode: mode
         """
         def radial_func(l, x):
-            return self.A_n(l) * Sp.hankelh2(l, self.k_f * x)
+            return self.A_n(l) * Bf.hankelh2(l, self.k_f * x)
 
         out = self.radial_mode_superposition(radial_func, r, theta, t, mode)
         return out
@@ -260,7 +260,7 @@ class ScatteringField(BaseYosioka, BaseScattering):
         :param mode: mode
         """
         def radial_func(l, x):
-            return self.B_n(l) * Sp.besselj(l, self.k_s * x)
+            return self.B_n(l) * Bf.besselj(l, self.k_s * x)
 
         out = self.radial_mode_superposition(radial_func, r, theta, t, mode)
         return out
@@ -279,7 +279,7 @@ class ScatteringField(BaseYosioka, BaseScattering):
         """
         return (
             self.A_n(n)
-            * self.k_f * Sp.d1_hankelh2(n, self.k_f * r)
+            * self.k_f * Bf.d1_hankelh2(n, self.k_f * r)
         )
 
     def V_theta_sc(
@@ -294,7 +294,7 @@ class ScatteringField(BaseYosioka, BaseScattering):
         :param n: mode
         :param r: radial coordinate [m]
         """
-        return self.A_n(n) * Sp.hankelh2(n, self.k_f * r) / r
+        return self.A_n(n) * Bf.hankelh2(n, self.k_f * r) / r
 
     # -------------------------------------------------------------------------
     # Coefficients
@@ -324,19 +324,19 @@ class ScatteringField(BaseYosioka, BaseScattering):
         """
         term1 = (
             self.lambda_rho * self.k_f *
-            Sp.besselj(n, self.x_s) * Sp.d1_besselj(n, self.x_f)
+            Bf.besselj(n, self.x_s) * Bf.d1_besselj(n, self.x_f)
         )
         term2 = (
-            self.k_s * Sp.d1_besselj(n, self.x_s)
-            * Sp.besselj(n, self.x_f)
+            self.k_s * Bf.d1_besselj(n, self.x_s)
+            * Bf.besselj(n, self.x_f)
         )
         term3 = (
-            self.k_s * Sp.d1_besselj(n, self.x_s)
-            * Sp.hankelh2(n, self.x_f)
+            self.k_s * Bf.d1_besselj(n, self.x_s)
+            * Bf.hankelh2(n, self.x_f)
         )
         term4 = (
             self.lambda_rho * self.k_f *
-            Sp.besselj(n, self.x_s) * Sp.d1_hankelh2(n, self.x_f)
+            Bf.besselj(n, self.x_s) * Bf.d1_hankelh2(n, self.x_f)
         )
         out = (term1 - term2) / (term3 - term4)
         out *= self.A_in(n)
@@ -349,12 +349,12 @@ class ScatteringField(BaseYosioka, BaseScattering):
         out = 1j * self.k_f
         out /= self.x_f ** 2
         term1 = (
-            self.k_s * Sp.d1_besselj(n, self.x_s)
-            * Sp.hankelh2(n, self.x_f)
+            self.k_s * Bf.d1_besselj(n, self.x_s)
+            * Bf.hankelh2(n, self.x_f)
         )
         term2 = (
             self.lambda_rho * self.k_f *
-            Sp.besselj(n, self.x_s) * Sp.d1_hankelh2(n, self.x_f)
+            Bf.besselj(n, self.x_s) * Bf.d1_hankelh2(n, self.x_f)
         )
         out /= (term1 - term2)
         out *= self.A_in(n)
