@@ -3,8 +3,8 @@ import unittest
 import numpy as np
 
 from osaft import BackgroundField, InviscidFluid, WaveType
+from osaft.core.functions import BesselFunctions as Bf
 from osaft.core.functions import LegendreFunctions as Leg
-from osaft.core.functions import SpecialFunctions as Sp
 from osaft.core.functions import full_range
 from osaft.solutions.base_scattering import (
     BaseScattering,
@@ -127,7 +127,7 @@ class TestBaseScattering(unittest.TestCase):
             return out
 
         def radial_func(n, r):
-            return Sp.besselj(n, r) - 1j * Sp.hankelh1(n, r)
+            return Bf.besselj(n, r) - 1j * Bf.hankelh1(n, r)
 
         for mode in [0, 1, 2, 3, 4, None]:
             r = self.cls.R_0 * (np.random.random() + 1)
@@ -153,7 +153,7 @@ class TestBaseScattering(unittest.TestCase):
             return out
 
         def tangential_func(n, r):
-            return Sp.besselj(n, r) - 1j * Sp.hankelh1(n, r)
+            return Bf.besselj(n, r) - 1j * Bf.hankelh1(n, r)
 
         for mode in [0, 1, 2, 3, 4, None]:
             r = self.cls.R_0 * (np.random.random() + 1)
@@ -171,7 +171,7 @@ class TestBaseScattering(unittest.TestCase):
     def test_V_r_i(self) -> None:
         def V_r_i(n, r):
             out = self.cls.field.A_in(n) * self.cls.k_f
-            out *= Sp.d1_besselj(n, self.cls.k_f * r)
+            out *= Bf.d1_besselj(n, self.cls.k_f * r)
             return out
 
         for n in np.arange(5):
@@ -182,7 +182,7 @@ class TestBaseScattering(unittest.TestCase):
     def test_V_theta_i(self) -> None:
         def V_theta_i(n, r):
             out = self.cls.field.A_in(n)
-            out *= Sp.besselj(n, self.cls.k_f * r) / r
+            out *= Bf.besselj(n, self.cls.k_f * r) / r
             return out
 
         for n in np.arange(5):
